taped.live_audio_pipelining — taped 0.0.2 documentation

# taped.live_audio_pipelining

class `taped.live_audio_pipelining.` `CallableDeque`

`taped.live_audio_pipelining.` `chk_to_fv_viz`(chk: numpy.ndarray, chk_to_fv=<function log_max_chk_to_fv>, fv_to_str=functools.partial(<function multipart_fv_str>, num_to_viz_str=<function ascii_levels>, fv_num_sep='\n'))

  Takes a chk and returns a string representing the fv. Meant to be displayed dynamically

`taped.live_audio_pipelining.` `dflt_chk_to_fv`(chk: numpy.ndarray, gain=50)

  A chk_to_fv that has to do with volume

`taped.live_audio_pipelining.` `log_max_chk_to_fv`(chk: numpy.ndarray, gain=50)

  A chk_to_fv that has to do with volume

`taped.live_audio_pipelining.` `make_and_consume_iterator`(iterator_func, *iterator_func_args, **iterator_func_kwargs)

  make an consume and iterator